/*
 * Copyright (c) 2008 Jesper Karlsson & David Gustafsson
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>
#include <gtk/gtk.h>
#include <libxfce4ui/libxfce4ui.h>

#include "xfbib-bibtex.h"
#include "xfbib-state.h"
#include "xfbib-window.h"
#include "xfbib-file-io.h"

gboolean
cb_window_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	gtk_main_quit();
	return FALSE;
}

int
main (int argc, char **argv)
{
	XfbibState *state;
	XfbibBibtex *elements;
	GtkWidget *window;
	GError *error = NULL;
	gboolean version = FALSE;
	gchar **input_files = NULL, *output_file = NULL;
	gint n, i;
        GOptionContext *opt_contxt;
	GOptionEntry options[] = {
		{ "version", 'V', 0, G_OPTION_ARG_NONE, &version, "Print program version", NULL },
		{ "output-file", 'o', 0, G_OPTION_ARG_FILENAME, &output_file,
		"Filename of the output file when merging multiple files", NULL },
		{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &input_files, "Filename" },
		{ NULL, 0, 0, 0, 0, NULL, NULL },
	};

	setlocale( LC_MESSAGES, "");
    bindtextdomain( PACKAGE, LOCALEDIR);
    textdomain (PACKAGE);

	gtk_init(&argc, &argv);
	
	/**/
//	g_log_set_always_fatal (G_LOG_LEVEL_CRITICAL);
	/**/

        opt_contxt = g_option_context_new(NULL);
        g_option_context_add_main_entries(opt_contxt, options, N_("main_entries"));
	g_option_context_set_description(opt_contxt, _("Report bugs to http://bugs.xfce.org/\n"));
        if (!g_option_context_parse(opt_contxt, &argc, &argv, &error)) {
		g_printerr(_("Error parsing: %s\n"), error->message);
		g_error_free(error);
		g_option_context_free(opt_contxt);
		return EXIT_FAILURE;
	}

        g_option_context_free(opt_contxt);

	if (version) {
		g_print(PACKAGE_STRING "\n");
		return EXIT_SUCCESS;
	}

	state = xfbib_state_new();

	elements = xfbib_bibtex_new();
	xfbib_state_set_bibtex_elements(state, elements);

	window = xfbib_window_new();
  	xfbib_window_set_title(XFBIB_WINDOW(window), NULL);

        g_signal_connect (G_OBJECT(window), "destroy",
			G_CALLBACK(cb_window_destroy_event), NULL);

	xfbib_state_set_window(state, window);

	
	if (input_files != NULL) {
		n = g_strv_length(input_files);
		
		if (n == 1) {
			if ((output_file = xfbib_file_io_open(input_files[0])) != NULL) {
				xfbib_state_set_filename(state, output_file);
				xfbib_window_set_title(XFBIB_WINDOW(window), output_file);
			}
		} else {
			/* Multiple files */
			/* TODO: Check that output file is present */
			if (output_file == NULL) {
				g_print(_("Error merging files, no output file specified\n"));
				return EXIT_FAILURE;
			}
			xfbib_state_set_filename(state, output_file);
			xfbib_window_set_title(XFBIB_WINDOW(window), output_file);

			for (i = 0; i < n; i++) {
				xfbib_file_io_open(input_files[i]);
			}
		}
		g_strfreev(input_files);

	}

	gtk_widget_show_all(window);
	gtk_main();

	return EXIT_SUCCESS;
}
