/*
 * Copyright (c) 2008 Jesper Karlsson & David Gustafsson
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <gtk/gtk.h>

#include "xfbib-bibtex-comment.h"

struct _XfbibBibtexComment
{
	GObject parent;
	GObject *owner;
	gchar *str;
};

typedef struct _XfbibBibtexCommentClass
{
	GObjectClass parent;
} XfbibBibtexCommentClass;

static void xfbib_bibtex_comment_class_init(XfbibBibtexCommentClass *klass);

static void xfbib_bibtex_comment_init(XfbibBibtexComment *instance);
static void xfbib_bibtex_comment_finalize(GObject *obj);

G_DEFINE_TYPE(XfbibBibtexComment, xfbib_bibtex_comment, G_TYPE_OBJECT)

static void
xfbib_bibtex_comment_class_init(XfbibBibtexCommentClass *klass)
{
	GObjectClass *object_class = (GObjectClass *)klass;
	object_class->finalize = xfbib_bibtex_comment_finalize;
}

static void
xfbib_bibtex_comment_init(XfbibBibtexComment *instance)
{
	instance->str = NULL;
}

static void
xfbib_bibtex_comment_finalize(GObject *obj)
{
	g_free(XFBIB_BIBTEX_COMMENT(obj)->str);
	G_OBJECT_CLASS(xfbib_bibtex_comment_parent_class)->finalize(obj);
}

XfbibBibtexComment *
xfbib_bibtex_comment_new(GObject *obj, const gchar *str)
{
	XfbibBibtexComment *comment;
	comment = g_object_new(XFBIB_TYPE_BIBTEX_COMMENT, NULL);
	comment->owner = obj;
	comment->str = g_strdup(str);
	return comment;
}

GObject *
xfbib_bibtex_comment_get_owner(XfbibBibtexComment *comment)
{
	g_return_val_if_fail(XFBIB_IS_BIBTEX_COMMENT(comment), NULL);
	return comment->owner;
}
	

gchar *
xfbib_bibtex_comment_get(XfbibBibtexComment *comment)
{
	g_return_val_if_fail(XFBIB_IS_BIBTEX_COMMENT(comment), NULL);
	return comment->str;
}
